@@ -1,7 +1,7 @@
 mod client;
 mod user;
 
-pub use oauth2::TokenResponse;
+pub use oauth2::{TokenResponse, CsrfToken};
 
 pub use user::PhabricatorUser;
 pub use client::PhabOAuthClient;
\ No newline at end of file
